@@ -13,13 +13,15 @@
 ##############################################################################
 import decimal
 import doctest
-import unittest
 import unicodedata
+import unittest
+
 
 # pylint:disable=protected-access,inherit-non-class,blacklisted-name
 # pylint:disable=attribute-defined-outside-init
 
-class InterfaceConformanceTestsMixin(object):
+
+class InterfaceConformanceTestsMixin:
 
     def _getTargetClass(self):
         raise NotImplementedError
@@ -45,7 +47,6 @@ class InterfaceConformanceTestsMixin(object):
         __traceback_info__ = cls
         for iface in self._getTargetInterfaces():
             verifyClass(iface, cls)
-        return verifyClass
 
     def test_instance_conforms_to_iface(self):
         from zope.interface.verify import verifyObject
@@ -53,7 +54,6 @@ class InterfaceConformanceTestsMixin(object):
         __traceback_info__ = instance
         for iface in self._getTargetInterfaces():
             verifyObject(iface, instance)
-        return verifyObject
 
     def test_iface_is_first_in_sro(self):
         from zope.interface import implementedBy
@@ -63,16 +63,18 @@ class InterfaceConformanceTestsMixin(object):
         self.assertIs(self._getTargetInterface(), implemented.__sro__[1])
 
     def test_implements_consistent__sro__(self):
-        from zope.interface import ro
         from zope.interface import implementedBy
+        from zope.interface import ro
         __traceback_info__ = implementedBy(self._getTargetClass()).__sro__
-        self.assertTrue(ro.is_consistent(implementedBy(self._getTargetClass())))
+        self.assertTrue(
+            ro.is_consistent(implementedBy(self._getTargetClass())))
 
     def test_iface_consistent_ro(self):
         from zope.interface import ro
         __traceback_info__ = self._getTargetInterface().__iro__
         self.assertTrue(ro.is_consistent(self._getTargetInterface()))
 
+
 class EqualityTestsMixin(InterfaceConformanceTestsMixin):
 
     def test_is_hashable(self):
@@ -110,8 +112,8 @@ class EqualityTestsMixin(InterfaceConformanceTestsMixin):
         # Hash equality does not imply equal objects.
         # Our implementation only considers property names,
         # not values. That's OK, a dict still does the right thing.
-        field1 = self._makeOne(title=u'foo')
-        field2 = self._makeOne(title=u'bar')
+        field1 = self._makeOne(title='foo')
+        field2 = self._makeOne(title='bar')
         self.assertIsNot(field1, field2)
         self.assertNotEqual(field1, field2)
         self.assertEqual(hash(field1), hash(field2))
@@ -130,13 +132,13 @@ class EqualityTestsMixin(InterfaceConformanceTestsMixin):
             pass
         right = self._makeOneFromClass(Derived)
         self.assertNotEqual(left, right)
-        self.assertTrue(left != right)
+        self.assertNotEqual(left, right)
 
     def test___eq___same_type_different_attrs(self):
         left = self._makeOne(required=True)
         right = self._makeOne(required=False)
         self.assertNotEqual(left, right)
-        self.assertTrue(left != right)
+        self.assertNotEqual(left, right)
 
     def test___eq___same_type_same_attrs(self):
         left = self._makeOne()
@@ -144,10 +146,10 @@ class EqualityTestsMixin(InterfaceConformanceTestsMixin):
 
         right = self._makeOne()
         self.assertEqual(left, right)
-        self.assertFalse(left != right)
+        self.assertEqual(left, right)
 
 
-class OrderableMissingValueMixin(object):
+class OrderableMissingValueMixin:
     mvm_missing_value = -1
     mvm_default = 0
 
@@ -167,7 +169,7 @@ class OrderableMissingValueMixin(object):
         self.assertEqual(self.mvm_missing_value, field.missing_value)
 
 
-class OrderableTestsMixin(object):
+class OrderableTestsMixin:
 
     def assertRaisesTooBig(self, field, value):
         from zope.schema.interfaces import TooBig
@@ -219,7 +221,7 @@ class OrderableTestsMixin(object):
             self.assertRaisesTooBig(field, value)
 
 
-class LenTestsMixin(object):
+class LenTestsMixin:
 
     def assertRaisesTooLong(self, field, value):
         from zope.schema.interfaces import TooLong
@@ -242,9 +244,10 @@ class LenTestsMixin(object):
         self.assertEqual(TooShort.TOO_SMALL, ex.violation_direction)
 
 
-class WrongTypeTestsMixin(object):
+class WrongTypeTestsMixin:
 
-    def assertRaisesWrongType(self, field_or_meth, expected_type, *args, **kwargs):
+    def assertRaisesWrongType(self, field_or_meth, expected_type,
+                              *args, **kwargs):
         from zope.schema.interfaces import WrongType
         field = None
         with self.assertRaises(WrongType) as exc:
@@ -265,7 +268,6 @@ class WrongTypeTestsMixin(object):
             # A single keyword argument
             self.assertIs(ex.value, kwargs.popitem()[1])
 
-
     def assertAllRaiseWrongType(self, field, expected_type, *values):
         for value in values:
             __traceback_info__ = value
@@ -376,8 +378,9 @@ class DefaultPropertyTests(unittest.TestCase):
 
     def test___get___w_defaultFactory_w_ICAF_w_check(self):
         from zope.interface import directlyProvides
-        from zope.schema._bootstrapinterfaces \
-            import IContextAwareDefaultFactory
+
+        from zope.schema._bootstrapinterfaces import \
+            IContextAwareDefaultFactory
         _checked = []
 
         def _check(inst, value):
@@ -439,7 +442,7 @@ class FieldTests(EqualityTestsMixin,
         # value_type and key_type are automatically picked up
         field.value_type = self._makeOne()
         # Make sure the formatting works also with fields that have a title
-        field.key_type = self._makeOne(title=u'Key Type')
+        field.key_type = self._makeOne(title='Key Type')
         doc = field.getDoc()
         self.assertIn('.. rubric:: Key Type', doc)
         self.assertIn('.. rubric:: Value Type', doc)
@@ -473,7 +476,9 @@ class FieldTests(EqualityTestsMixin,
             """)
         )
 
-        field = self._makeOne(title=u'A title', description=u"""Multiline description.
+        field = self._makeOne(
+            title='A title',
+            description="""Multiline description.
 
         Some lines have leading whitespace.
 
@@ -503,18 +508,19 @@ class FieldTests(EqualityTestsMixin,
         # The exact value of the description is preserved,
         # allowing for MessageID objects.
         import textwrap
+
         from zope.i18nmessageid import MessageFactory
 
         msg_factory = MessageFactory('zope')
 
-        description = msg_factory(u"""Multiline description.
+        description = msg_factory("""Multiline description.
 
         Some lines have leading whitespace.
 
         It gets stripped.
         """)
 
-        title = msg_factory(u'A title')
+        title = msg_factory('A title')
 
         field = self._makeOne(title=title, description=description)
 
@@ -545,7 +551,7 @@ class FieldTests(EqualityTestsMixin,
 
         description = None
 
-        title = u'A title'
+        title = 'A title'
 
         field = self._makeOne(title=title, description=description)
 
@@ -567,10 +573,10 @@ class FieldTests(EqualityTestsMixin,
     def test_ctor_defaults(self):
 
         field = self._makeOne()
-        self.assertEqual(field.__name__, u'')
-        self.assertEqual(field.__doc__, u'')
-        self.assertEqual(field.title, u'')
-        self.assertEqual(field.description, u'')
+        self.assertEqual(field.__name__, '')
+        self.assertEqual(field.__doc__, '')
+        self.assertEqual(field.title, '')
+        self.assertEqual(field.description, '')
         self.assertEqual(field.required, True)
         self.assertEqual(field.readonly, False)
         self.assertEqual(field.constraint(object()), True)
@@ -581,27 +587,27 @@ class FieldTests(EqualityTestsMixin,
 
     def test_ctor_w_title_wo_description(self):
 
-        field = self._makeOne(u'TITLE')
-        self.assertEqual(field.__name__, u'')
-        self.assertEqual(field.__doc__, u'TITLE')
-        self.assertEqual(field.title, u'TITLE')
-        self.assertEqual(field.description, u'')
+        field = self._makeOne('TITLE')
+        self.assertEqual(field.__name__, '')
+        self.assertEqual(field.__doc__, 'TITLE')
+        self.assertEqual(field.title, 'TITLE')
+        self.assertEqual(field.description, '')
 
     def test_ctor_wo_title_w_description(self):
 
-        field = self._makeOne(description=u'DESC')
-        self.assertEqual(field.__name__, u'')
-        self.assertEqual(field.__doc__, u'DESC')
-        self.assertEqual(field.title, u'')
-        self.assertEqual(field.description, u'DESC')
+        field = self._makeOne(description='DESC')
+        self.assertEqual(field.__name__, '')
+        self.assertEqual(field.__doc__, 'DESC')
+        self.assertEqual(field.title, '')
+        self.assertEqual(field.description, 'DESC')
 
     def test_ctor_w_both_title_and_description(self):
 
-        field = self._makeOne(u'TITLE', u'DESC', u'NAME')
-        self.assertEqual(field.__name__, u'NAME')
-        self.assertEqual(field.__doc__, u'TITLE\n\nDESC')
-        self.assertEqual(field.title, u'TITLE')
-        self.assertEqual(field.description, u'DESC')
+        field = self._makeOne('TITLE', 'DESC', 'NAME')
+        self.assertEqual(field.__name__, 'NAME')
+        self.assertEqual(field.__doc__, 'TITLE\n\nDESC')
+        self.assertEqual(field.title, 'TITLE')
+        self.assertEqual(field.description, 'DESC')
 
     def test_ctor_order_madness(self):
         klass = self._getTargetClass()
@@ -680,7 +686,7 @@ class FieldTests(EqualityTestsMixin,
     def test_validate_missing_not_required(self):
         missing = object()
 
-        field = self._makeOne(
+        field = self._makeOne(  # pragma: no branch
             required=False, missing_value=missing, constraint=lambda x: False,
         )
         self.assertEqual(field.validate(missing), None)  # doesn't raise
@@ -689,14 +695,16 @@ class FieldTests(EqualityTestsMixin,
         from zope.schema._bootstrapinterfaces import RequiredMissing
         missing = object()
 
-        field = self._makeOne(
+        field = self._makeOne(  # pragma: no branch
             required=True, missing_value=missing, constraint=lambda x: False,
         )
         self.assertRaises(RequiredMissing, field.validate, missing)
 
     def test_validate_wrong_type(self):
 
-        field = self._makeOne(required=True, constraint=lambda x: False)
+        field = self._makeOne(  # pragma: no branch
+            required=True, constraint=lambda x: False,
+        )
         field._type = str
         self.assertRaisesWrongType(field, str, 1)
 
@@ -814,7 +822,7 @@ class ContainerTests(EqualityTestsMixin,
     def test__validate_collection_but_not_iterable(self):
         cont = self._makeOne()
 
-        class Dummy(object):
+        class Dummy:
             def __contains__(self, item):
                 raise AssertionError("Not called")
         cont._validate(Dummy())  # doesn't raise
@@ -822,7 +830,7 @@ class ContainerTests(EqualityTestsMixin,
     def test__validate_not_collection_but_iterable(self):
         cont = self._makeOne()
 
-        class Dummy(object):
+        class Dummy:
             def __iter__(self):
                 return iter(())
         cont._validate(Dummy())  # doesn't raise
@@ -849,7 +857,7 @@ class IterableTests(ContainerTests):
         from zope.schema._bootstrapinterfaces import NotAnIterator
         itr = self._makeOne()
 
-        class Dummy(object):
+        class Dummy:
             def __contains__(self, item):
                 raise AssertionError("Not called")
         dummy = Dummy()
@@ -934,9 +942,8 @@ class TextTests(EqualityTestsMixin,
         return IText
 
     def test_ctor_defaults(self):
-        from zope.schema._compat import text_type
         txt = self._makeOne()
-        self.assertEqual(txt._type, text_type)
+        self.assertEqual(txt._type, str)
 
     def test_validate_wrong_types(self):
         field = self._makeOne()
@@ -961,18 +968,18 @@ class TextTests(EqualityTestsMixin,
     def test_validate_not_required(self):
 
         field = self._makeOne(required=False)
-        field.validate(u'')
-        field.validate(u'abc')
-        field.validate(u'abc\ndef')
+        field.validate('')
+        field.validate('abc')
+        field.validate('abc\ndef')
         field.validate(None)
 
     def test_validate_required(self):
         from zope.schema.interfaces import RequiredMissing
 
         field = self._makeOne()
-        field.validate(u'')
-        field.validate(u'abc')
-        field.validate(u'abc\ndef')
+        field.validate('')
+        field.validate('abc')
+        field.validate('abc\ndef')
         self.assertRaises(RequiredMissing, field.validate, None)
 
     def test_fromUnicode_miss(self):
@@ -981,12 +988,13 @@ class TextTests(EqualityTestsMixin,
         self.assertRaisesWrongType(txt.fromUnicode, txt._type, deadbeef)
 
     def test_fromUnicode_hit(self):
-        deadbeef = u'DEADBEEF'
+        deadbeef = 'DEADBEEF'
         txt = self._makeOne()
         self.assertEqual(txt.fromUnicode(deadbeef), deadbeef)
 
     def test_normalization(self):
-        deadbeef = unicodedata.normalize('NFD', b'\xc3\x84\xc3\x96\xc3\x9c'.decode('utf-8'))
+        deadbeef = unicodedata.normalize(
+            'NFD', b'\xc3\x84\xc3\x96\xc3\x9c'.decode('utf-8'))
         txt = self._makeOne()
         self.assertEqual(txt.unicode_normalization, 'NFC')
         self.assertEqual(
@@ -1016,6 +1024,7 @@ class TextTests(EqualityTestsMixin,
         # see https://github.com/zopefoundation/zope.schema/issues/90
         import pickle
         orig_makeOne = self._makeOne
+
         def makeOne(**kwargs):
             result = orig_makeOne(**kwargs)
             if not kwargs:
@@ -1059,24 +1068,24 @@ class TextLineTests(EqualityTestsMixin,
     def test_validate_not_required(self):
 
         field = self._makeOne(required=False)
-        field.validate(u'')
-        field.validate(u'abc')
+        field.validate('')
+        field.validate('abc')
         field.validate(None)
 
     def test_validate_required(self):
         from zope.schema.interfaces import RequiredMissing
 
         field = self._makeOne()
-        field.validate(u'')
-        field.validate(u'abc')
+        field.validate('')
+        field.validate('abc')
         self.assertRaises(RequiredMissing, field.validate, None)
 
     def test_constraint(self):
 
         field = self._makeOne()
-        self.assertEqual(field.constraint(u''), True)
-        self.assertEqual(field.constraint(u'abc'), True)
-        self.assertEqual(field.constraint(u'abc\ndef'), False)
+        self.assertEqual(field.constraint(''), True)
+        self.assertEqual(field.constraint('abc'), True)
+        self.assertEqual(field.constraint('abc\ndef'), False)
 
 
 class PasswordTests(EqualityTestsMixin,
@@ -1109,16 +1118,16 @@ class PasswordTests(EqualityTestsMixin,
     def test_validate_not_required(self):
 
         field = self._makeOne(required=False)
-        field.validate(u'')
-        field.validate(u'abc')
+        field.validate('')
+        field.validate('abc')
         field.validate(None)
 
     def test_validate_required(self):
         from zope.schema.interfaces import RequiredMissing
 
         field = self._makeOne()
-        field.validate(u'')
-        field.validate(u'abc')
+        field.validate('')
+        field.validate('abc')
         self.assertRaises(RequiredMissing, field.validate, None)
 
     def test_validate_unchanged_not_already_set(self):
@@ -1137,12 +1146,13 @@ class PasswordTests(EqualityTestsMixin,
     def test_constraint(self):
 
         field = self._makeOne()
-        self.assertEqual(field.constraint(u''), True)
-        self.assertEqual(field.constraint(u'abc'), True)
-        self.assertEqual(field.constraint(u'abc\ndef'), False)
+        self.assertEqual(field.constraint(''), True)
+        self.assertEqual(field.constraint('abc'), True)
+        self.assertEqual(field.constraint('abc\ndef'), False)
 
 
 class BoolTests(EqualityTestsMixin,
+                WrongTypeTestsMixin,
                 unittest.TestCase):
 
     def _getTargetClass(self):
@@ -1157,11 +1167,20 @@ class BoolTests(EqualityTestsMixin,
         txt = self._makeOne()
         self.assertEqual(txt._type, bool)
 
+    def test_validate_wrong_type(self):
+        boo = self._makeOne()
+        self.assertRaisesWrongType(boo, boo._type, '')
+
     def test__validate_w_int(self):
         boo = self._makeOne()
         boo._validate(0)  # doesn't raise
         boo._validate(1)  # doesn't raise
 
+    def test__validate_w_bool(self):
+        boo = self._makeOne()
+        boo._validate(False)  # doesn't raise
+        boo._validate(True)   # doesn't raise
+
     def test_set_w_int(self):
         boo = self._makeOne(__name__='boo')
         inst = DummyInst()
@@ -1170,20 +1189,28 @@ class BoolTests(EqualityTestsMixin,
         boo.set(inst, 1)
         self.assertEqual(inst.boo, True)
 
+    def test_set_w_bool(self):
+        boo = self._makeOne(__name__='boo')
+        inst = DummyInst()
+        boo.set(inst, False)
+        self.assertEqual(inst.boo, False)
+        boo.set(inst, True)
+        self.assertEqual(inst.boo, True)
+
     def test_fromUnicode_miss(self):
 
         txt = self._makeOne()
-        self.assertEqual(txt.fromUnicode(u''), False)
-        self.assertEqual(txt.fromUnicode(u'0'), False)
-        self.assertEqual(txt.fromUnicode(u'1'), False)
-        self.assertEqual(txt.fromUnicode(u'False'), False)
-        self.assertEqual(txt.fromUnicode(u'false'), False)
+        self.assertEqual(txt.fromUnicode(''), False)
+        self.assertEqual(txt.fromUnicode('0'), False)
+        self.assertEqual(txt.fromUnicode('1'), False)
+        self.assertEqual(txt.fromUnicode('False'), False)
+        self.assertEqual(txt.fromUnicode('false'), False)
 
     def test_fromUnicode_hit(self):
 
         txt = self._makeOne()
-        self.assertEqual(txt.fromUnicode(u'True'), True)
-        self.assertEqual(txt.fromUnicode(u'true'), True)
+        self.assertEqual(txt.fromUnicode('True'), True)
+        self.assertEqual(txt.fromUnicode('true'), True)
 
 
 class NumberTests(EqualityTestsMixin,
@@ -1200,16 +1227,20 @@ class NumberTests(EqualityTestsMixin,
         return INumber
 
     def test_class_conforms_to_iface(self):
-        from zope.schema._bootstrapinterfaces import IFromUnicode
+        from zope.interface.verify import verifyClass
+
         from zope.schema._bootstrapinterfaces import IFromBytes
-        verifyClass = super(NumberTests, self).test_class_conforms_to_iface()
+        from zope.schema._bootstrapinterfaces import IFromUnicode
+        super().test_class_conforms_to_iface()
         verifyClass(IFromUnicode, self._getTargetClass())
         verifyClass(IFromBytes, self._getTargetClass())
 
     def test_instance_conforms_to_iface(self):
-        from zope.schema._bootstrapinterfaces import IFromUnicode
+        from zope.interface.verify import verifyObject
+
         from zope.schema._bootstrapinterfaces import IFromBytes
-        verifyObject = super(NumberTests, self).test_instance_conforms_to_iface()
+        from zope.schema._bootstrapinterfaces import IFromUnicode
+        super().test_instance_conforms_to_iface()
         verifyObject(IFromUnicode, self._makeOne())
         verifyObject(IFromBytes, self._makeOne())
 
@@ -1224,6 +1255,7 @@ class ComplexTests(NumberTests):
         from zope.schema.interfaces import IComplex
         return IComplex
 
+
 class RealTests(WrongTypeTestsMixin,
                 NumberTests):
 
@@ -1238,8 +1270,10 @@ class RealTests(WrongTypeTestsMixin,
     def test_ctor_real_min_max(self):
         from fractions import Fraction
 
-        self.assertRaisesWrongType(self._makeOne, self._getTargetClass()._type, min='')
-        self.assertRaisesWrongType(self._makeOne, self._getTargetClass()._type, max='')
+        self.assertRaisesWrongType(
+            self._makeOne, self._getTargetClass()._type, min='')
+        self.assertRaisesWrongType(
+            self._makeOne, self._getTargetClass()._type, max='')
 
         field = self._makeOne(min=Fraction(1, 2), max=2)
         field.validate(1.0)
@@ -1287,16 +1321,16 @@ class IntegralTests(RationalTests):
 
     def test_fromUnicode_miss(self):
         txt = self._makeOne()
-        self.assertRaises(ValueError, txt.fromUnicode, u'')
-        self.assertRaises(ValueError, txt.fromUnicode, u'False')
-        self.assertRaises(ValueError, txt.fromUnicode, u'True')
+        self.assertRaises(ValueError, txt.fromUnicode, '')
+        self.assertRaises(ValueError, txt.fromUnicode, 'False')
+        self.assertRaises(ValueError, txt.fromUnicode, 'True')
 
     def test_fromUnicode_hit(self):
 
         txt = self._makeOne()
-        self.assertEqual(txt.fromUnicode(u'0'), 0)
-        self.assertEqual(txt.fromUnicode(u'1'), 1)
-        self.assertEqual(txt.fromUnicode(u'-1'), -1)
+        self.assertEqual(txt.fromUnicode('0'), 0)
+        self.assertEqual(txt.fromUnicode('1'), 1)
+        self.assertEqual(txt.fromUnicode('-1'), -1)
 
 
 class IntTests(IntegralTests):
@@ -1310,9 +1344,8 @@ class IntTests(IntegralTests):
         return IInt
 
     def test_ctor_defaults(self):
-        from zope.schema._compat import integer_types
         txt = self._makeOne()
-        self.assertEqual(txt._type, integer_types)
+        self.assertEqual(txt._type, int)
 
 
 class DecimalTests(NumberTests):
@@ -1352,23 +1385,23 @@ class DecimalTests(NumberTests):
     def test_fromUnicode_miss(self):
         from zope.schema.interfaces import ValidationError
         flt = self._makeOne()
-        self.assertRaises(ValueError, flt.fromUnicode, u'')
-        self.assertRaises(ValueError, flt.fromUnicode, u'abc')
+        self.assertRaises(ValueError, flt.fromUnicode, '')
+        self.assertRaises(ValueError, flt.fromUnicode, 'abc')
         with self.assertRaises(ValueError) as exc:
-            flt.fromUnicode(u'1.4G')
+            flt.fromUnicode('1.4G')
 
         value_error = exc.exception
         self.assertIs(value_error.field, flt)
-        self.assertEqual(value_error.value, u'1.4G')
+        self.assertEqual(value_error.value, '1.4G')
         self.assertIsInstance(value_error, ValidationError)
 
     def test_fromUnicode_hit(self):
         from decimal import Decimal
 
         flt = self._makeOne()
-        self.assertEqual(flt.fromUnicode(u'0'), Decimal('0.0'))
-        self.assertEqual(flt.fromUnicode(u'1.23'), Decimal('1.23'))
-        self.assertEqual(flt.fromUnicode(u'12345.6'), Decimal('12345.6'))
+        self.assertEqual(flt.fromUnicode('0'), Decimal('0.0'))
+        self.assertEqual(flt.fromUnicode('1.23'), Decimal('1.23'))
+        self.assertEqual(flt.fromUnicode('12345.6'), Decimal('12345.6'))
 
 
 class ObjectTests(EqualityTestsMixin,
@@ -1394,7 +1427,8 @@ class ObjectTests(EqualityTestsMixin,
     def _makeOneFromClass(self, cls, schema=None, *args, **kw):
         if schema is None:
             schema = self._makeSchema()
-        return super(ObjectTests, self)._makeOneFromClass(cls, schema, *args, **kw)
+        return super()._makeOneFromClass(
+            cls, schema, *args, **kw)
 
     def _makeSchema(self, **kw):
         from zope.interface import Interface
@@ -1410,8 +1444,9 @@ class ObjectTests(EqualityTestsMixin,
     def _makeCycles(self):
         from zope.interface import Interface
         from zope.interface import implementer
-        from zope.schema import Object
+
         from zope.schema import List
+        from zope.schema import Object
         from zope.schema._messageid import _
 
         class IUnit(Interface):
@@ -1421,13 +1456,13 @@ class ObjectTests(EqualityTestsMixin,
                 title=_("Boss"),
                 description=_("Boss description"),
                 required=False,
-                )
+            )
             members = List(
                 value_type=Object(schema=Interface),
                 title=_("Member List"),
                 description=_("Member list description"),
                 required=False,
-                )
+            )
 
         class IPerson(Interface):
             """A schema that participate to a cycle"""
@@ -1436,19 +1471,19 @@ class ObjectTests(EqualityTestsMixin,
                 title=_("Unit"),
                 description=_("Unit description"),
                 required=False,
-                )
+            )
 
         IUnit['boss'].schema = IPerson
         IUnit['members'].value_type.schema = IPerson
 
         @implementer(IUnit)
-        class Unit(object):
+        class Unit:
             def __init__(self, person, person_list):
                 self.boss = person
                 self.members = person_list
 
         @implementer(IPerson)
-        class Person(object):
+        class Person:
             def __init__(self, unit):
                 self.unit = unit
 
@@ -1456,11 +1491,13 @@ class ObjectTests(EqualityTestsMixin,
 
     def test_class_conforms_to_IObject(self):
         from zope.interface.verify import verifyClass
+
         from zope.schema.interfaces import IObject
         verifyClass(IObject, self._getTargetClass())
 
     def test_instance_conforms_to_IObject(self):
         from zope.interface.verify import verifyObject
+
         from zope.schema.interfaces import IObject
         verifyObject(IObject, self._makeOne())
 
@@ -1484,8 +1521,8 @@ class ObjectTests(EqualityTestsMixin,
         objf.validate(object())  # doesn't raise
 
     def test__validate_w_value_not_providing_schema(self):
-        from zope.schema.interfaces import SchemaNotProvided
         from zope.schema._bootstrapfields import Text
+        from zope.schema.interfaces import SchemaNotProvided
         schema = self._makeSchema(foo=Text(), bar=Text())
         objf = self._makeOne(schema)
         bad_value = object()
@@ -1499,13 +1536,14 @@ class ObjectTests(EqualityTestsMixin,
 
     def test__validate_w_value_providing_schema_but_missing_fields(self):
         from zope.interface import implementer
-        from zope.schema.interfaces import SchemaNotFullyImplemented
-        from zope.schema.interfaces import SchemaNotCorrectlyImplemented
+
         from zope.schema._bootstrapfields import Text
+        from zope.schema.interfaces import SchemaNotCorrectlyImplemented
+        from zope.schema.interfaces import SchemaNotFullyImplemented
         schema = self._makeSchema(foo=Text(), bar=Text())
 
         @implementer(schema)
-        class Broken(object):
+        class Broken:
             pass
 
         objf = self._makeOne(schema)
@@ -1546,15 +1584,15 @@ class ObjectTests(EqualityTestsMixin,
 
     def test__validate_w_value_providing_schema_but_invalid_fields(self):
         from zope.interface import implementer
-        from zope.schema.interfaces import SchemaNotCorrectlyImplemented
-        from zope.schema.interfaces import RequiredMissing
-        from zope.schema.interfaces import WrongType
+
         from zope.schema._bootstrapfields import Text
-        from zope.schema._compat import text_type
+        from zope.schema.interfaces import RequiredMissing
+        from zope.schema.interfaces import SchemaNotCorrectlyImplemented
+        from zope.schema.interfaces import WrongType
         schema = self._makeSchema(foo=Text(), bar=Text())
 
         @implementer(schema)
-        class Broken(object):
+        class Broken:
             foo = None
             bar = 1
 
@@ -1583,10 +1621,11 @@ class ObjectTests(EqualityTestsMixin,
         self.assertEqual(err.args, ('foo',))
         err = errors[1]
         self.assertIsInstance(err, WrongType)
-        self.assertEqual(err.args, (1, text_type, 'bar'))
+        self.assertEqual(err.args, (1, str, 'bar'))
 
     def test__validate_w_value_providing_schema(self):
         from zope.interface import implementer
+
         from zope.schema._bootstrapfields import Text
         from zope.schema._field import Choice
 
@@ -1597,9 +1636,9 @@ class ObjectTests(EqualityTestsMixin,
         )
 
         @implementer(schema)
-        class OK(object):
-            foo = u'Foo'
-            bar = u'Bar'
+        class OK:
+            foo = 'Foo'
+            bar = 'Bar'
             baz = 2
         objf = self._makeOne(schema)
         objf.validate(OK())  # doesn't raise
@@ -1661,9 +1700,10 @@ class ObjectTests(EqualityTestsMixin,
     def test_set_emits_IBOAE(self):
         from zope.event import subscribers
         from zope.interface import implementer
-        from zope.schema.interfaces import IBeforeObjectAssignedEvent
+
         from zope.schema._bootstrapfields import Text
         from zope.schema._field import Choice
+        from zope.schema.interfaces import IBeforeObjectAssignedEvent
 
         schema = self._makeSchema(
             foo=Text(),
@@ -1672,9 +1712,9 @@ class ObjectTests(EqualityTestsMixin,
         )
 
         @implementer(schema)
-        class OK(object):
-            foo = u'Foo'
-            bar = u'Bar'
+        class OK:
+            foo = 'Foo'
+            bar = 'Bar'
             baz = 2
         log = []
         subscribers.append(log.append)
@@ -1692,6 +1732,7 @@ class ObjectTests(EqualityTestsMixin,
     def test_set_allows_IBOAE_subscr_to_replace_value(self):
         from zope.event import subscribers
         from zope.interface import implementer
+
         from zope.schema._bootstrapfields import Text
         from zope.schema._field import Choice
 
@@ -1702,13 +1743,13 @@ class ObjectTests(EqualityTestsMixin,
         )
 
         @implementer(schema)
-        class OK(object):
-            def __init__(self, foo=u'Foo', bar=u'Bar', baz=2):
+        class OK:
+            def __init__(self, foo='Foo', bar='Bar', baz=2):
                 self.foo = foo
                 self.bar = bar
                 self.baz = baz
         ok1 = OK()
-        ok2 = OK(u'Foo2', u'Bar2', 3)
+        ok2 = OK('Foo2', 'Bar2', 3)
         log = []
         subscribers.append(log.append)
 
@@ -1726,12 +1767,13 @@ class ObjectTests(EqualityTestsMixin,
         self.assertEqual(log[-1].context, inst)
 
     def test_validates_invariants_by_default(self):
-        from zope.interface import invariant
         from zope.interface import Interface
-        from zope.interface import implementer
         from zope.interface import Invalid
-        from zope.schema import Text
+        from zope.interface import implementer
+        from zope.interface import invariant
+
         from zope.schema import Bytes
+        from zope.schema import Text
 
         class ISchema(Interface):
 
@@ -1740,7 +1782,7 @@ class ObjectTests(EqualityTestsMixin,
 
             @invariant
             def check_foo(self):
-                if self.foo == u'bar':
+                if self.foo == 'bar':
                     raise Invalid("Foo is not valid")
 
             @invariant
@@ -1749,18 +1791,17 @@ class ObjectTests(EqualityTestsMixin,
                     raise Invalid("Bar is not valid")
 
         @implementer(ISchema)
-        class O(object):
-            foo = u''
+        class Obj:
+            foo = ''
             bar = b''
 
-
         field = self._makeOne(ISchema)
-        inst = O()
+        inst = Obj()
 
         # Fine at first
         field.validate(inst)
 
-        inst.foo = u'bar'
+        inst.foo = 'bar'
         errors = self._getErrors(field.validate, inst)
         self.assertEqual(len(errors), 1)
         self.assertEqual(errors[0].args[0], "Foo is not valid")
@@ -1772,7 +1813,7 @@ class ObjectTests(EqualityTestsMixin,
         self.assertEqual(errors[0].args[0], "Bar is not valid")
 
         # Both invalid
-        inst.foo = u'bar'
+        inst.foo = 'bar'
         errors = self._getErrors(field.validate, inst)
         self.assertEqual(len(errors), 2)
         errors.sort(key=lambda i: i.args)
@@ -1804,55 +1845,56 @@ class ObjectTests(EqualityTestsMixin,
 
         # Actual implementation works
         @interface.implementer(IValueType)
-        class ValueType(object):
+        class ValueType:
             "The value type"
 
-
         field.validate(ValueType())
 
     def test_bound_field_of_collection_with_choice(self):
         # https://github.com/zopefoundation/zope.schema/issues/17
-        from zope.interface import Interface, implementer
         from zope.interface import Attribute
+        from zope.interface import Interface
+        from zope.interface import implementer
 
-        from zope.schema import Choice, Object, Set
+        from zope.schema import Choice
+        from zope.schema import Object
+        from zope.schema import Set
         from zope.schema.fieldproperty import FieldProperty
-        from zope.schema.interfaces import IContextSourceBinder
-        from zope.schema.interfaces import WrongContainedType
         from zope.schema.interfaces import ConstraintNotSatisfied
+        from zope.schema.interfaces import IContextSourceBinder
         from zope.schema.interfaces import SchemaNotCorrectlyImplemented
+        from zope.schema.interfaces import WrongContainedType
         from zope.schema.vocabulary import SimpleVocabulary
 
-
         @implementer(IContextSourceBinder)
-        class EnumContext(object):
+        class EnumContext:
             def __call__(self, context):
                 return SimpleVocabulary.fromValues(list(context))
 
         class IMultipleChoice(Interface):
             choices = Set(value_type=Choice(source=EnumContext()))
             # Provide a regular attribute to prove that binding doesn't
-            # choke. NOTE: We don't actually verify the existence of this attribute.
+            # choke. NOTE: We don't actually verify the existence of this
+            # attribute.
             non_field = Attribute("An attribute")
 
         @implementer(IMultipleChoice)
-        class Choices(object):
+        class Choices:
 
             def __init__(self, choices):
                 self.choices = choices
 
             def __iter__(self):
                 # EnumContext calls this to make the vocabulary.
-                # Fields of the schema of the IObject are bound to the value being
-                # validated.
+                # Fields of the schema of the IObject are bound to the value
+                # being validated.
                 return iter(range(5))
 
         class IFavorites(Interface):
-            fav = Object(title=u"Favorites number", schema=IMultipleChoice)
-
+            fav = Object(title="Favorites number", schema=IMultipleChoice)
 
         @implementer(IFavorites)
-        class Favorites(object):
+        class Favorites:
             fav = FieldProperty(IFavorites['fav'])
 
         # must not raise
@@ -1907,23 +1949,22 @@ class ObjectTests(EqualityTestsMixin,
         self.assertIn(":Must Provide: :class:", doc)
 
 
-class DummyInst(object):
+class DummyInst:
     missing_value = object()
 
     def __init__(self, exc=None):
         self._exc = exc
 
     def validate(self, value):
-        if self._exc is not None:
+        if self._exc is not None:  # pragma: no branch
             raise self._exc()
 
 
 def test_suite():
     import zope.schema._bootstrapfields
-    from zope.testing.renormalizing import IGNORE_EXCEPTION_MODULE_IN_PYTHON2
     suite = unittest.defaultTestLoader.loadTestsFromName(__name__)
     suite.addTests(doctest.DocTestSuite(
         zope.schema._bootstrapfields,
-        optionflags=doctest.ELLIPSIS|IGNORE_EXCEPTION_MODULE_IN_PYTHON2
+        optionflags=doctest.ELLIPSIS
     ))
     return suite
